<?php

namespace Drupal\Tests\data_pipelines\Unit\Plugin\DatasetDestination;

use Drupal\Component\Serialization\Json;
use Drupal\data_pipelines\Plugin\DatasetDestination\JsonDestination;
use Drupal\Tests\data_pipelines\Kernel\DatasetKernelTestBase;

/**
 * Tests the JSON destination.
 *
 * @group data_pipelines
 * @coversDefaultClass \Drupal\data_pipelines\Plugin\DatasetDestination\JsonDestination
 */
class JsonDestinationTest extends DatasetKernelTestBase {

  /**
   * @covers ::saveDataSet
   * @covers ::deleteDataSet
   */
  public function testSaveDataDeleteData() {
    $destinationId = $this->randomMachineName();
    $destination = $this->createTestMemoryDestination(['id' => $destinationId]);
    $dataset = $this->createTestDataset(['destinations' => $destination]);

    $fileSystem = \Drupal::service('file_system');
    $streamWrapperManager = \Drupal::service('stream_wrapper_manager');
    $configuration = [
      'scheme' => 'public',
      'dir' => '',
    ];
    $plugin_id = 'foo';
    $plugin_definition = [];
    $destinationPlugin = new JsonDestination($configuration, $plugin_id, $plugin_definition, $fileSystem, $streamWrapperManager);

    $this->assertTrue($destinationPlugin->beginProcessing($dataset));
    $this->assertTrue($destinationPlugin->processChunk($dataset, iterator_to_array($dataset->getDataIterator())));
    $file_path = 'public://' . $dataset->getMachineName() . '.json';
    $this->assertEquals(Json::encode(iterator_to_array($dataset->getDataIterator())), file_get_contents($file_path));
    $this->assertTrue($destinationPlugin->deleteDataSet($dataset, $destination));
    $this->assertFileDoesNotExist($file_path);
  }

}
